
#include <p18cxxx.h>
#include "system\typedefs.h"                        // Required
#include "system\usb\usb.h"                         // Required
#include "io_cfg.h"                                 // Required

#include "system\usb\usb_compile_time_validation.h" // Optional
#include "user\user.h"                              // Modifiable
#include "CartBike.h"




/** C O N F I G U R A T I O N  S E T T I N G S *******************************/
#pragma config PLLDIV = 5	// Divide by 5 (20 MHz oscillator input)
#pragma config CPUDIV = OSC1_PLL2	// [OSC1/OSC2 Src: /1][96 MHz PLL Src: /2]
#pragma config USBDIV = 2	//U SB clock source comes from the 96 MHz PLL divided by 2
#pragma config FOSC = HSPLL_HS	// HS oscillator, PLL enabled, HS used by USB
#pragma config FCMEN = OFF	//F ail-Safe Clock Monitor disabled
#pragma config IESO = OFF	// Oscillator Switchover mode disabled
#pragma config PWRT = OFF	// PWRT disabled //power up timer
#pragma config BOR = ON	// Brown-out Reset enabled in hardware only (SBOREN is disabled)
#pragma config BORV = 3	// Minimum setting
#pragma config VREGEN = ON	// USB voltage regulator enabled
#pragma config WDT = OFF	// HW Disabled - SW Controlled
#pragma config WDTPS = 32768	// 1:32768
#pragma config MCLRE = ON	// MCLR pin enabled; RE3 input pin disabled
#pragma config LPT1OSC = OFF	// Timer1 configured for higher power operation
#pragma config PBADEN = OFF	// PORTB<4:0> pins are configured as digital I/O on Reset
#pragma config CCP2MX = ON	// CCP2 input/output is multiplexed with RC1
#pragma config STVREN = OFF	// Stack full/underflow will cause Reset
#pragma config LVP = OFF	// Single-Supply ICSP disabled
//#pragma config ICPRT = OFF	// ICPORT disabled
#pragma config XINST = OFF	// Instruction set extension and Indexed Addressing mode disabled (Legacy mode)
#pragma config DEBUG = OFF	// Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins
#pragma config CP0 = OFF	//Block 0 (000800-001FFFh) not code-protected
#pragma config CP1 = OFF	//Block 1 (002000-003FFFh) not code-protected
#pragma config CP2 = OFF	//Block 2 (004000-005FFFh) not code-protected
#pragma config CP3 = OFF	//Block 3 (006000-007FFFh) not code-protected
#pragma config CPB = OFF	//Boot block (000000-0007FFh) not code-protected
#pragma config CPD = OFF	//Data EEPROM not code-protected
#pragma config WRT0 = OFF	//Block 0 (000800-001FFFh) not write-protected
#pragma config WRT1 = OFF	//Block 1 (002000-003FFFh) not write-protected
#pragma config WRT2 = OFF	//Block 2 (004000-005FFFh) not write-protected
#pragma config WRT3 = OFF	//Block 3 (006000-007FFFh) not write-protected
#pragma config WRTB = OFF	//Configuration registers (300000-3000FFh) not write-protected
#pragma config WRTC = OFF	//Boot block (000000-0007FFh) not write-protected
#pragma config WRTD = OFF	//Data EEPROM not write-protected
#pragma config EBTR0 = OFF	//Block 0 (000800-001FFFh) not protected from table reads executed in other blocks
#pragma config EBTR1 = OFF	//Block 1 (002000-003FFFh) not protected from table reads executed in other blocks
#pragma config EBTR2 = OFF	//Block 2 (004000-005FFFh) not protected from table reads executed in other blocks
#pragma config EBTR3 = OFF	//Block 3 (006000-007FFFh) not protected from table reads executed in other blocks
#pragma config EBTRB = OFF	//Boot block (000000-0007FFh) not protected from table reads executed in other blocks



#pragma udata

int encoder_count; 
char mybits;
char icount;

const rom char verstring[] = "RaveCart\0";

void InterruptHandlerHigh (void); // prototype for int handler

// High priority interrupt vector
#pragma code InterruptVectorHigh = 0x08
void
InterruptVectorHigh (void)
{ 
  _asm
    goto InterruptHandlerHigh //jump to interrupt routine
  _endasm
}

void InterruptHandlerLow (void); // prototype for int handler

#pragma code InterruptVector = 0x18
// low priority interrupt vector
void
InterruptVectorLow (void)
{ 
  _asm
    goto InterruptHandlerLow //jump to interrupt routine
  _endasm
}



static void InitializeSystem(void);
void USBTasks(void);

#pragma code


/******************************************************************************
 * Function:        void main(void)
 *****************************************************************************/
void main(void)
{
	unsigned int longcount;
	unsigned char i, pplace=0,charindex,stringlength=0;

    //default text on the LED panels. Raspberry Pi will overwrite this through USB
	unsigned char USBdata[] = {0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,'B','I','K','E',' ','R','A','V','E',0}; 
	
    InitializeSystem();

    ClearScrollMessage();
    
       	for(i=16; i< 64; i++){
	    	if(USBdata[i] == 0){
		    	stringlength = i-16; //not the actual length of the string. 16 bytes longer.
		    	break;
		    }	
	    }
	    
    
    		for(i=0;i<stringlength;i++){
		    	
		    	charindex = fromAscii(USBdata[(stringlength-i)+15]);
		    	if(charindex == ' '){
			    		pplace+=7;
			    } else {
		    		printchar(charindex,pplace);
		    	
		    		pplace+= GetAlphaPixelLength(charindex) +2;//2 pixels between characters
		    	}
    		}	
 
    
  			SetScrollLength(pplace);	
    
  				
  			


    
    while(1)
    {
     
	  LoadVolume();
      FullTransversal();

    }
}


static void InitializeSystem(void)
{

    mInitializeUSBDriver();         // See usbdrv.h
    USBCheckBusStatus(); //JWB
    UserInit();                     // See user.c & .h


}


void USBTasks(void)
{
    USBCheckBusStatus();                    // Must use polling method  -->  usbdrv.c
    if(UCFGbits.UTEYE!=1)
        USBDriverService();                 // Interrupt or polling method

}


#pragma interrupt InterruptHandlerHigh

void InterruptHandlerHigh (void)
{
}

#pragma interrupt InterruptHandlerLow

void InterruptHandlerLow(void)
{
}
	

